@@ -126,7 +126,7 @@ def setup_settings(settings, is_prod=False, **kwargs):
     else:
         default_settings.update({
             'DEBUG': True,
-            'EMAIL_BACKEND': 'basement.email.FileBasedEmailBackend',
+            'EMAIL_BACKEND': 'djrunner.email.FileBasedEmailBackend',
             'CACHES': {
                 'default': {
                     'BACKEND': 'django.core.cache.backends.dummy.DummyCache'
@@ -143,11 +143,11 @@ def setup_settings(settings, is_prod=False, **kwargs):
 
         try:
             mod = importlib.import_module(app)
+        except ModuleNotFoundError:
+            continue
 
-            if hasattr(mod, 'setup_settings'):
-                mod.setup_settings(settings, is_prod=False, **kwargs)
-        except Exception:
-            pass
+        if hasattr(mod, 'setup_settings'):
+            mod.setup_settings(settings, is_prod=False, **kwargs)
 
 
 def setup_urlpatterns(
